@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2006-2007 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
@@ -142,6 +142,24 @@ typedef enum
 GType thunar_icon_size_get_type (void) G_GNUC_CONST;
 
 
+#define THUNAR_TYPE_THUMBNAIL_MODE (thunar_thumbnail_mode_get_type ())
+
+/**
+ * ThunarThumbnailsShow:
+ * @THUNAR_THUMBNAIL_MODE_NEVER      : never show thumbnails.
+ * @THUNAR_THUMBNAIL_MODE_ONLY_LOCAL : only show thumbnails on local filesystems.
+ * @THUNAR_THUMBNAIL_MODE_ALWAYS     : always show thumbnails (everywhere).
+ **/
+typedef enum
+{
+  THUNAR_THUMBNAIL_MODE_NEVER,
+  THUNAR_THUMBNAIL_MODE_ONLY_LOCAL,
+  THUNAR_THUMBNAIL_MODE_ALWAYS
+} ThunarThumbnailMode;
+
+GType thunar_thumbnail_mode_get_type (void) G_GNUC_CONST;
+
+
 #define THUNAR_TYPE_RECURSIVE_PERMISSIONS (thunar_recursive_permissions_get_type ())
 
 /**
